@@ -21,14 +21,14 @@ class TestFileTree : public QObject
 public:
     TestFileTree();
 
-private:
+private Q_SLOTS:
     void testFileName();
     void testFileSize();
     void testFilePath();
     void testDuplicate();
 
 private:
-    std::unique_ptr<File> fl;
+    const std::unique_ptr<const File> m_file;
 };
 
 #endif
